static void boot_constants(HV *stash, AV *tags_all) {
    av_extend(tags_all, 410);
    newCONSTSUB(stash, "ACCESS_CONTROL_DISABLE", newSViv(XCB_ACCESS_CONTROL_DISABLE));
    av_push(tags_all, newSVpvn("ACCESS_CONTROL_DISABLE", 22));
    newCONSTSUB(stash, "ACCESS_CONTROL_ENABLE", newSViv(XCB_ACCESS_CONTROL_ENABLE));
    av_push(tags_all, newSVpvn("ACCESS_CONTROL_ENABLE", 21));
    newCONSTSUB(stash, "ALLOW_ASYNC_BOTH", newSViv(XCB_ALLOW_ASYNC_BOTH));
    av_push(tags_all, newSVpvn("ALLOW_ASYNC_BOTH", 16));
    newCONSTSUB(stash, "ALLOW_ASYNC_KEYBOARD", newSViv(XCB_ALLOW_ASYNC_KEYBOARD));
    av_push(tags_all, newSVpvn("ALLOW_ASYNC_KEYBOARD", 20));
    newCONSTSUB(stash, "ALLOW_ASYNC_POINTER", newSViv(XCB_ALLOW_ASYNC_POINTER));
    av_push(tags_all, newSVpvn("ALLOW_ASYNC_POINTER", 19));
    newCONSTSUB(stash, "ALLOW_REPLAY_KEYBOARD", newSViv(XCB_ALLOW_REPLAY_KEYBOARD));
    av_push(tags_all, newSVpvn("ALLOW_REPLAY_KEYBOARD", 21));
    newCONSTSUB(stash, "ALLOW_REPLAY_POINTER", newSViv(XCB_ALLOW_REPLAY_POINTER));
    av_push(tags_all, newSVpvn("ALLOW_REPLAY_POINTER", 20));
    newCONSTSUB(stash, "ALLOW_SYNC_BOTH", newSViv(XCB_ALLOW_SYNC_BOTH));
    av_push(tags_all, newSVpvn("ALLOW_SYNC_BOTH", 15));
    newCONSTSUB(stash, "ALLOW_SYNC_KEYBOARD", newSViv(XCB_ALLOW_SYNC_KEYBOARD));
    av_push(tags_all, newSVpvn("ALLOW_SYNC_KEYBOARD", 19));
    newCONSTSUB(stash, "ALLOW_SYNC_POINTER", newSViv(XCB_ALLOW_SYNC_POINTER));
    av_push(tags_all, newSVpvn("ALLOW_SYNC_POINTER", 18));
    newCONSTSUB(stash, "ARC_MODE_CHORD", newSViv(XCB_ARC_MODE_CHORD));
    av_push(tags_all, newSVpvn("ARC_MODE_CHORD", 14));
    newCONSTSUB(stash, "ARC_MODE_PIE_SLICE", newSViv(XCB_ARC_MODE_PIE_SLICE));
    av_push(tags_all, newSVpvn("ARC_MODE_PIE_SLICE", 18));
    newCONSTSUB(stash, "ATOM_ANY", newSViv(XCB_ATOM_ANY));
    av_push(tags_all, newSVpvn("ATOM_ANY", 8));
    newCONSTSUB(stash, "ATOM_ARC", newSViv(XCB_ATOM_ARC));
    av_push(tags_all, newSVpvn("ATOM_ARC", 8));
    newCONSTSUB(stash, "ATOM_ATOM", newSViv(XCB_ATOM_ATOM));
    av_push(tags_all, newSVpvn("ATOM_ATOM", 9));
    newCONSTSUB(stash, "ATOM_BITMAP", newSViv(XCB_ATOM_BITMAP));
    av_push(tags_all, newSVpvn("ATOM_BITMAP", 11));
    newCONSTSUB(stash, "ATOM_CAP_HEIGHT", newSViv(XCB_ATOM_CAP_HEIGHT));
    av_push(tags_all, newSVpvn("ATOM_CAP_HEIGHT", 15));
    newCONSTSUB(stash, "ATOM_CARDINAL", newSViv(XCB_ATOM_CARDINAL));
    av_push(tags_all, newSVpvn("ATOM_CARDINAL", 13));
    newCONSTSUB(stash, "ATOM_COLORMAP", newSViv(XCB_ATOM_COLORMAP));
    av_push(tags_all, newSVpvn("ATOM_COLORMAP", 13));
    newCONSTSUB(stash, "ATOM_COPYRIGHT", newSViv(XCB_ATOM_COPYRIGHT));
    av_push(tags_all, newSVpvn("ATOM_COPYRIGHT", 14));
    newCONSTSUB(stash, "ATOM_CURSOR", newSViv(XCB_ATOM_CURSOR));
    av_push(tags_all, newSVpvn("ATOM_CURSOR", 11));
    newCONSTSUB(stash, "ATOM_CUT_BUFFER0", newSViv(XCB_ATOM_CUT_BUFFER0));
    av_push(tags_all, newSVpvn("ATOM_CUT_BUFFER0", 16));
    newCONSTSUB(stash, "ATOM_CUT_BUFFER1", newSViv(XCB_ATOM_CUT_BUFFER1));
    av_push(tags_all, newSVpvn("ATOM_CUT_BUFFER1", 16));
    newCONSTSUB(stash, "ATOM_CUT_BUFFER2", newSViv(XCB_ATOM_CUT_BUFFER2));
    av_push(tags_all, newSVpvn("ATOM_CUT_BUFFER2", 16));
    newCONSTSUB(stash, "ATOM_CUT_BUFFER3", newSViv(XCB_ATOM_CUT_BUFFER3));
    av_push(tags_all, newSVpvn("ATOM_CUT_BUFFER3", 16));
    newCONSTSUB(stash, "ATOM_CUT_BUFFER4", newSViv(XCB_ATOM_CUT_BUFFER4));
    av_push(tags_all, newSVpvn("ATOM_CUT_BUFFER4", 16));
    newCONSTSUB(stash, "ATOM_CUT_BUFFER5", newSViv(XCB_ATOM_CUT_BUFFER5));
    av_push(tags_all, newSVpvn("ATOM_CUT_BUFFER5", 16));
    newCONSTSUB(stash, "ATOM_CUT_BUFFER6", newSViv(XCB_ATOM_CUT_BUFFER6));
    av_push(tags_all, newSVpvn("ATOM_CUT_BUFFER6", 16));
    newCONSTSUB(stash, "ATOM_CUT_BUFFER7", newSViv(XCB_ATOM_CUT_BUFFER7));
    av_push(tags_all, newSVpvn("ATOM_CUT_BUFFER7", 16));
    newCONSTSUB(stash, "ATOM_DRAWABLE", newSViv(XCB_ATOM_DRAWABLE));
    av_push(tags_all, newSVpvn("ATOM_DRAWABLE", 13));
    newCONSTSUB(stash, "ATOM_END_SPACE", newSViv(XCB_ATOM_END_SPACE));
    av_push(tags_all, newSVpvn("ATOM_END_SPACE", 14));
    newCONSTSUB(stash, "ATOM_FAMILY_NAME", newSViv(XCB_ATOM_FAMILY_NAME));
    av_push(tags_all, newSVpvn("ATOM_FAMILY_NAME", 16));
    newCONSTSUB(stash, "ATOM_FONT", newSViv(XCB_ATOM_FONT));
    av_push(tags_all, newSVpvn("ATOM_FONT", 9));
    newCONSTSUB(stash, "ATOM_FONT_NAME", newSViv(XCB_ATOM_FONT_NAME));
    av_push(tags_all, newSVpvn("ATOM_FONT_NAME", 14));
    newCONSTSUB(stash, "ATOM_FULL_NAME", newSViv(XCB_ATOM_FULL_NAME));
    av_push(tags_all, newSVpvn("ATOM_FULL_NAME", 14));
    newCONSTSUB(stash, "ATOM_INTEGER", newSViv(XCB_ATOM_INTEGER));
    av_push(tags_all, newSVpvn("ATOM_INTEGER", 12));
    newCONSTSUB(stash, "ATOM_ITALIC_ANGLE", newSViv(XCB_ATOM_ITALIC_ANGLE));
    av_push(tags_all, newSVpvn("ATOM_ITALIC_ANGLE", 17));
    newCONSTSUB(stash, "ATOM_MAX_SPACE", newSViv(XCB_ATOM_MAX_SPACE));
    av_push(tags_all, newSVpvn("ATOM_MAX_SPACE", 14));
    newCONSTSUB(stash, "ATOM_MIN_SPACE", newSViv(XCB_ATOM_MIN_SPACE));
    av_push(tags_all, newSVpvn("ATOM_MIN_SPACE", 14));
    newCONSTSUB(stash, "ATOM_NONE", newSViv(XCB_ATOM_NONE));
    av_push(tags_all, newSVpvn("ATOM_NONE", 9));
    newCONSTSUB(stash, "ATOM_NORM_SPACE", newSViv(XCB_ATOM_NORM_SPACE));
    av_push(tags_all, newSVpvn("ATOM_NORM_SPACE", 15));
    newCONSTSUB(stash, "ATOM_NOTICE", newSViv(XCB_ATOM_NOTICE));
    av_push(tags_all, newSVpvn("ATOM_NOTICE", 11));
    newCONSTSUB(stash, "ATOM_PIXMAP", newSViv(XCB_ATOM_PIXMAP));
    av_push(tags_all, newSVpvn("ATOM_PIXMAP", 11));
    newCONSTSUB(stash, "ATOM_POINT", newSViv(XCB_ATOM_POINT));
    av_push(tags_all, newSVpvn("ATOM_POINT", 10));
    newCONSTSUB(stash, "ATOM_POINT_SIZE", newSViv(XCB_ATOM_POINT_SIZE));
    av_push(tags_all, newSVpvn("ATOM_POINT_SIZE", 15));
    newCONSTSUB(stash, "ATOM_PRIMARY", newSViv(XCB_ATOM_PRIMARY));
    av_push(tags_all, newSVpvn("ATOM_PRIMARY", 12));
    newCONSTSUB(stash, "ATOM_QUAD_WIDTH", newSViv(XCB_ATOM_QUAD_WIDTH));
    av_push(tags_all, newSVpvn("ATOM_QUAD_WIDTH", 15));
    newCONSTSUB(stash, "ATOM_RECTANGLE", newSViv(XCB_ATOM_RECTANGLE));
    av_push(tags_all, newSVpvn("ATOM_RECTANGLE", 14));
    newCONSTSUB(stash, "ATOM_RESOLUTION", newSViv(XCB_ATOM_RESOLUTION));
    av_push(tags_all, newSVpvn("ATOM_RESOLUTION", 15));
    newCONSTSUB(stash, "ATOM_RESOURCE_MANAGER", newSViv(XCB_ATOM_RESOURCE_MANAGER));
    av_push(tags_all, newSVpvn("ATOM_RESOURCE_MANAGER", 21));
    newCONSTSUB(stash, "ATOM_RGB_BEST_MAP", newSViv(XCB_ATOM_RGB_BEST_MAP));
    av_push(tags_all, newSVpvn("ATOM_RGB_BEST_MAP", 17));
    newCONSTSUB(stash, "ATOM_RGB_BLUE_MAP", newSViv(XCB_ATOM_RGB_BLUE_MAP));
    av_push(tags_all, newSVpvn("ATOM_RGB_BLUE_MAP", 17));
    newCONSTSUB(stash, "ATOM_RGB_COLOR_MAP", newSViv(XCB_ATOM_RGB_COLOR_MAP));
    av_push(tags_all, newSVpvn("ATOM_RGB_COLOR_MAP", 18));
    newCONSTSUB(stash, "ATOM_RGB_DEFAULT_MAP", newSViv(XCB_ATOM_RGB_DEFAULT_MAP));
    av_push(tags_all, newSVpvn("ATOM_RGB_DEFAULT_MAP", 20));
    newCONSTSUB(stash, "ATOM_RGB_GRAY_MAP", newSViv(XCB_ATOM_RGB_GRAY_MAP));
    av_push(tags_all, newSVpvn("ATOM_RGB_GRAY_MAP", 17));
    newCONSTSUB(stash, "ATOM_RGB_GREEN_MAP", newSViv(XCB_ATOM_RGB_GREEN_MAP));
    av_push(tags_all, newSVpvn("ATOM_RGB_GREEN_MAP", 18));
    newCONSTSUB(stash, "ATOM_RGB_RED_MAP", newSViv(XCB_ATOM_RGB_RED_MAP));
    av_push(tags_all, newSVpvn("ATOM_RGB_RED_MAP", 16));
    newCONSTSUB(stash, "ATOM_SECONDARY", newSViv(XCB_ATOM_SECONDARY));
    av_push(tags_all, newSVpvn("ATOM_SECONDARY", 14));
    newCONSTSUB(stash, "ATOM_STRIKEOUT_ASCENT", newSViv(XCB_ATOM_STRIKEOUT_ASCENT));
    av_push(tags_all, newSVpvn("ATOM_STRIKEOUT_ASCENT", 21));
    newCONSTSUB(stash, "ATOM_STRIKEOUT_DESCENT", newSViv(XCB_ATOM_STRIKEOUT_DESCENT));
    av_push(tags_all, newSVpvn("ATOM_STRIKEOUT_DESCENT", 22));
    newCONSTSUB(stash, "ATOM_STRING", newSViv(XCB_ATOM_STRING));
    av_push(tags_all, newSVpvn("ATOM_STRING", 11));
    newCONSTSUB(stash, "ATOM_SUBSCRIPT_X", newSViv(XCB_ATOM_SUBSCRIPT_X));
    av_push(tags_all, newSVpvn("ATOM_SUBSCRIPT_X", 16));
    newCONSTSUB(stash, "ATOM_SUBSCRIPT_Y", newSViv(XCB_ATOM_SUBSCRIPT_Y));
    av_push(tags_all, newSVpvn("ATOM_SUBSCRIPT_Y", 16));
    newCONSTSUB(stash, "ATOM_SUPERSCRIPT_X", newSViv(XCB_ATOM_SUPERSCRIPT_X));
    av_push(tags_all, newSVpvn("ATOM_SUPERSCRIPT_X", 18));
    newCONSTSUB(stash, "ATOM_SUPERSCRIPT_Y", newSViv(XCB_ATOM_SUPERSCRIPT_Y));
    av_push(tags_all, newSVpvn("ATOM_SUPERSCRIPT_Y", 18));
    newCONSTSUB(stash, "ATOM_UNDERLINE_POSITION", newSViv(XCB_ATOM_UNDERLINE_POSITION));
    av_push(tags_all, newSVpvn("ATOM_UNDERLINE_POSITION", 23));
    newCONSTSUB(stash, "ATOM_UNDERLINE_THICKNESS", newSViv(XCB_ATOM_UNDERLINE_THICKNESS));
    av_push(tags_all, newSVpvn("ATOM_UNDERLINE_THICKNESS", 24));
    newCONSTSUB(stash, "ATOM_VISUALID", newSViv(XCB_ATOM_VISUALID));
    av_push(tags_all, newSVpvn("ATOM_VISUALID", 13));
    newCONSTSUB(stash, "ATOM_WEIGHT", newSViv(XCB_ATOM_WEIGHT));
    av_push(tags_all, newSVpvn("ATOM_WEIGHT", 11));
    newCONSTSUB(stash, "ATOM_WINDOW", newSViv(XCB_ATOM_WINDOW));
    av_push(tags_all, newSVpvn("ATOM_WINDOW", 11));
    newCONSTSUB(stash, "ATOM_WM_CLASS", newSViv(XCB_ATOM_WM_CLASS));
    av_push(tags_all, newSVpvn("ATOM_WM_CLASS", 13));
    newCONSTSUB(stash, "ATOM_WM_CLIENT_MACHINE", newSViv(XCB_ATOM_WM_CLIENT_MACHINE));
    av_push(tags_all, newSVpvn("ATOM_WM_CLIENT_MACHINE", 22));
    newCONSTSUB(stash, "ATOM_WM_COMMAND", newSViv(XCB_ATOM_WM_COMMAND));
    av_push(tags_all, newSVpvn("ATOM_WM_COMMAND", 15));
    newCONSTSUB(stash, "ATOM_WM_HINTS", newSViv(XCB_ATOM_WM_HINTS));
    av_push(tags_all, newSVpvn("ATOM_WM_HINTS", 13));
    newCONSTSUB(stash, "ATOM_WM_ICON_NAME", newSViv(XCB_ATOM_WM_ICON_NAME));
    av_push(tags_all, newSVpvn("ATOM_WM_ICON_NAME", 17));
    newCONSTSUB(stash, "ATOM_WM_ICON_SIZE", newSViv(XCB_ATOM_WM_ICON_SIZE));
    av_push(tags_all, newSVpvn("ATOM_WM_ICON_SIZE", 17));
    newCONSTSUB(stash, "ATOM_WM_NAME", newSViv(XCB_ATOM_WM_NAME));
    av_push(tags_all, newSVpvn("ATOM_WM_NAME", 12));
    newCONSTSUB(stash, "ATOM_WM_NORMAL_HINTS", newSViv(XCB_ATOM_WM_NORMAL_HINTS));
    av_push(tags_all, newSVpvn("ATOM_WM_NORMAL_HINTS", 20));
    newCONSTSUB(stash, "ATOM_WM_SIZE_HINTS", newSViv(XCB_ATOM_WM_SIZE_HINTS));
    av_push(tags_all, newSVpvn("ATOM_WM_SIZE_HINTS", 18));
    newCONSTSUB(stash, "ATOM_WM_TRANSIENT_FOR", newSViv(XCB_ATOM_WM_TRANSIENT_FOR));
    av_push(tags_all, newSVpvn("ATOM_WM_TRANSIENT_FOR", 21));
    newCONSTSUB(stash, "ATOM_WM_ZOOM_HINTS", newSViv(XCB_ATOM_WM_ZOOM_HINTS));
    av_push(tags_all, newSVpvn("ATOM_WM_ZOOM_HINTS", 18));
    newCONSTSUB(stash, "ATOM_X_HEIGHT", newSViv(XCB_ATOM_X_HEIGHT));
    av_push(tags_all, newSVpvn("ATOM_X_HEIGHT", 13));
    newCONSTSUB(stash, "AUTO_REPEAT_MODE_DEFAULT", newSViv(XCB_AUTO_REPEAT_MODE_DEFAULT));
    av_push(tags_all, newSVpvn("AUTO_REPEAT_MODE_DEFAULT", 24));
    newCONSTSUB(stash, "AUTO_REPEAT_MODE_OFF", newSViv(XCB_AUTO_REPEAT_MODE_OFF));
    av_push(tags_all, newSVpvn("AUTO_REPEAT_MODE_OFF", 20));
    newCONSTSUB(stash, "AUTO_REPEAT_MODE_ON", newSViv(XCB_AUTO_REPEAT_MODE_ON));
    av_push(tags_all, newSVpvn("AUTO_REPEAT_MODE_ON", 19));
    newCONSTSUB(stash, "BACKING_STORE_ALWAYS", newSViv(XCB_BACKING_STORE_ALWAYS));
    av_push(tags_all, newSVpvn("BACKING_STORE_ALWAYS", 20));
    newCONSTSUB(stash, "BACKING_STORE_NOT_USEFUL", newSViv(XCB_BACKING_STORE_NOT_USEFUL));
    av_push(tags_all, newSVpvn("BACKING_STORE_NOT_USEFUL", 24));
    newCONSTSUB(stash, "BACKING_STORE_WHEN_MAPPED", newSViv(XCB_BACKING_STORE_WHEN_MAPPED));
    av_push(tags_all, newSVpvn("BACKING_STORE_WHEN_MAPPED", 25));
    newCONSTSUB(stash, "BACK_PIXMAP_NONE", newSViv(XCB_BACK_PIXMAP_NONE));
    av_push(tags_all, newSVpvn("BACK_PIXMAP_NONE", 16));
    newCONSTSUB(stash, "BACK_PIXMAP_PARENT_RELATIVE", newSViv(XCB_BACK_PIXMAP_PARENT_RELATIVE));
    av_push(tags_all, newSVpvn("BACK_PIXMAP_PARENT_RELATIVE", 27));
    newCONSTSUB(stash, "BLANKING_DEFAULT", newSViv(XCB_BLANKING_DEFAULT));
    av_push(tags_all, newSVpvn("BLANKING_DEFAULT", 16));
    newCONSTSUB(stash, "BLANKING_NOT_PREFERRED", newSViv(XCB_BLANKING_NOT_PREFERRED));
    av_push(tags_all, newSVpvn("BLANKING_NOT_PREFERRED", 22));
    newCONSTSUB(stash, "BLANKING_PREFERRED", newSViv(XCB_BLANKING_PREFERRED));
    av_push(tags_all, newSVpvn("BLANKING_PREFERRED", 18));
    newCONSTSUB(stash, "BUTTON_INDEX_1", newSViv(XCB_BUTTON_INDEX_1));
    av_push(tags_all, newSVpvn("BUTTON_INDEX_1", 14));
    newCONSTSUB(stash, "BUTTON_INDEX_2", newSViv(XCB_BUTTON_INDEX_2));
    av_push(tags_all, newSVpvn("BUTTON_INDEX_2", 14));
    newCONSTSUB(stash, "BUTTON_INDEX_3", newSViv(XCB_BUTTON_INDEX_3));
    av_push(tags_all, newSVpvn("BUTTON_INDEX_3", 14));
    newCONSTSUB(stash, "BUTTON_INDEX_4", newSViv(XCB_BUTTON_INDEX_4));
    av_push(tags_all, newSVpvn("BUTTON_INDEX_4", 14));
    newCONSTSUB(stash, "BUTTON_INDEX_5", newSViv(XCB_BUTTON_INDEX_5));
    av_push(tags_all, newSVpvn("BUTTON_INDEX_5", 14));
    newCONSTSUB(stash, "BUTTON_INDEX_ANY", newSViv(XCB_BUTTON_INDEX_ANY));
    av_push(tags_all, newSVpvn("BUTTON_INDEX_ANY", 16));
    newCONSTSUB(stash, "BUTTON_MASK_1", newSViv(XCB_BUTTON_MASK_1));
    av_push(tags_all, newSVpvn("BUTTON_MASK_1", 13));
    newCONSTSUB(stash, "BUTTON_MASK_2", newSViv(XCB_BUTTON_MASK_2));
    av_push(tags_all, newSVpvn("BUTTON_MASK_2", 13));
    newCONSTSUB(stash, "BUTTON_MASK_3", newSViv(XCB_BUTTON_MASK_3));
    av_push(tags_all, newSVpvn("BUTTON_MASK_3", 13));
    newCONSTSUB(stash, "BUTTON_MASK_4", newSViv(XCB_BUTTON_MASK_4));
    av_push(tags_all, newSVpvn("BUTTON_MASK_4", 13));
    newCONSTSUB(stash, "BUTTON_MASK_5", newSViv(XCB_BUTTON_MASK_5));
    av_push(tags_all, newSVpvn("BUTTON_MASK_5", 13));
    newCONSTSUB(stash, "BUTTON_MASK_ANY", newSViv(XCB_BUTTON_MASK_ANY));
    av_push(tags_all, newSVpvn("BUTTON_MASK_ANY", 15));
    newCONSTSUB(stash, "BUTTON_PRESS", newSViv(XCB_BUTTON_PRESS));
    av_push(tags_all, newSVpvn("BUTTON_PRESS", 12));
    newCONSTSUB(stash, "CAP_STYLE_BUTT", newSViv(XCB_CAP_STYLE_BUTT));
    av_push(tags_all, newSVpvn("CAP_STYLE_BUTT", 14));
    newCONSTSUB(stash, "CAP_STYLE_NOT_LAST", newSViv(XCB_CAP_STYLE_NOT_LAST));
    av_push(tags_all, newSVpvn("CAP_STYLE_NOT_LAST", 18));
    newCONSTSUB(stash, "CAP_STYLE_PROJECTING", newSViv(XCB_CAP_STYLE_PROJECTING));
    av_push(tags_all, newSVpvn("CAP_STYLE_PROJECTING", 20));
    newCONSTSUB(stash, "CAP_STYLE_ROUND", newSViv(XCB_CAP_STYLE_ROUND));
    av_push(tags_all, newSVpvn("CAP_STYLE_ROUND", 15));
    newCONSTSUB(stash, "CIRCULATE_LOWER_HIGHEST", newSViv(XCB_CIRCULATE_LOWER_HIGHEST));
    av_push(tags_all, newSVpvn("CIRCULATE_LOWER_HIGHEST", 23));
    newCONSTSUB(stash, "CIRCULATE_NOTIFY", newSViv(XCB_CIRCULATE_NOTIFY));
    av_push(tags_all, newSVpvn("CIRCULATE_NOTIFY", 16));
    newCONSTSUB(stash, "CIRCULATE_RAISE_LOWEST", newSViv(XCB_CIRCULATE_RAISE_LOWEST));
    av_push(tags_all, newSVpvn("CIRCULATE_RAISE_LOWEST", 22));
    newCONSTSUB(stash, "CLIENT_MESSAGE", newSViv(XCB_CLIENT_MESSAGE));
    av_push(tags_all, newSVpvn("CLIENT_MESSAGE", 14));
    newCONSTSUB(stash, "CLIP_ORDERING_UNSORTED", newSViv(XCB_CLIP_ORDERING_UNSORTED));
    av_push(tags_all, newSVpvn("CLIP_ORDERING_UNSORTED", 22));
    newCONSTSUB(stash, "CLIP_ORDERING_YX_BANDED", newSViv(XCB_CLIP_ORDERING_YX_BANDED));
    av_push(tags_all, newSVpvn("CLIP_ORDERING_YX_BANDED", 23));
    newCONSTSUB(stash, "CLIP_ORDERING_YX_SORTED", newSViv(XCB_CLIP_ORDERING_YX_SORTED));
    av_push(tags_all, newSVpvn("CLIP_ORDERING_YX_SORTED", 23));
    newCONSTSUB(stash, "CLIP_ORDERING_Y_SORTED", newSViv(XCB_CLIP_ORDERING_Y_SORTED));
    av_push(tags_all, newSVpvn("CLIP_ORDERING_Y_SORTED", 22));
    newCONSTSUB(stash, "CLOSE_DOWN_DESTROY_ALL", newSViv(XCB_CLOSE_DOWN_DESTROY_ALL));
    av_push(tags_all, newSVpvn("CLOSE_DOWN_DESTROY_ALL", 22));
    newCONSTSUB(stash, "CLOSE_DOWN_RETAIN_PERMANENT", newSViv(XCB_CLOSE_DOWN_RETAIN_PERMANENT));
    av_push(tags_all, newSVpvn("CLOSE_DOWN_RETAIN_PERMANENT", 27));
    newCONSTSUB(stash, "CLOSE_DOWN_RETAIN_TEMPORARY", newSViv(XCB_CLOSE_DOWN_RETAIN_TEMPORARY));
    av_push(tags_all, newSVpvn("CLOSE_DOWN_RETAIN_TEMPORARY", 27));
    newCONSTSUB(stash, "COLORMAP_ALLOC_ALL", newSViv(XCB_COLORMAP_ALLOC_ALL));
    av_push(tags_all, newSVpvn("COLORMAP_ALLOC_ALL", 18));
    newCONSTSUB(stash, "COLORMAP_ALLOC_NONE", newSViv(XCB_COLORMAP_ALLOC_NONE));
    av_push(tags_all, newSVpvn("COLORMAP_ALLOC_NONE", 19));
    newCONSTSUB(stash, "COLORMAP_NONE", newSViv(XCB_COLORMAP_NONE));
    av_push(tags_all, newSVpvn("COLORMAP_NONE", 13));
    newCONSTSUB(stash, "COLORMAP_NOTIFY", newSViv(XCB_COLORMAP_NOTIFY));
    av_push(tags_all, newSVpvn("COLORMAP_NOTIFY", 15));
    newCONSTSUB(stash, "COLORMAP_STATE_INSTALLED", newSViv(XCB_COLORMAP_STATE_INSTALLED));
    av_push(tags_all, newSVpvn("COLORMAP_STATE_INSTALLED", 24));
    newCONSTSUB(stash, "COLORMAP_STATE_UNINSTALLED", newSViv(XCB_COLORMAP_STATE_UNINSTALLED));
    av_push(tags_all, newSVpvn("COLORMAP_STATE_UNINSTALLED", 26));
    newCONSTSUB(stash, "COLOR_FLAG_BLUE", newSViv(XCB_COLOR_FLAG_BLUE));
    av_push(tags_all, newSVpvn("COLOR_FLAG_BLUE", 15));
    newCONSTSUB(stash, "COLOR_FLAG_GREEN", newSViv(XCB_COLOR_FLAG_GREEN));
    av_push(tags_all, newSVpvn("COLOR_FLAG_GREEN", 16));
    newCONSTSUB(stash, "COLOR_FLAG_RED", newSViv(XCB_COLOR_FLAG_RED));
    av_push(tags_all, newSVpvn("COLOR_FLAG_RED", 14));
    newCONSTSUB(stash, "CONFIGURE_NOTIFY", newSViv(XCB_CONFIGURE_NOTIFY));
    av_push(tags_all, newSVpvn("CONFIGURE_NOTIFY", 16));
    newCONSTSUB(stash, "CONFIGURE_REQUEST", newSViv(XCB_CONFIGURE_REQUEST));
    av_push(tags_all, newSVpvn("CONFIGURE_REQUEST", 17));
    newCONSTSUB(stash, "CONFIG_WINDOW_BORDER_WIDTH", newSViv(XCB_CONFIG_WINDOW_BORDER_WIDTH));
    av_push(tags_all, newSVpvn("CONFIG_WINDOW_BORDER_WIDTH", 26));
    newCONSTSUB(stash, "CONFIG_WINDOW_HEIGHT", newSViv(XCB_CONFIG_WINDOW_HEIGHT));
    av_push(tags_all, newSVpvn("CONFIG_WINDOW_HEIGHT", 20));
    newCONSTSUB(stash, "CONFIG_WINDOW_SIBLING", newSViv(XCB_CONFIG_WINDOW_SIBLING));
    av_push(tags_all, newSVpvn("CONFIG_WINDOW_SIBLING", 21));
    newCONSTSUB(stash, "CONFIG_WINDOW_STACK_MODE", newSViv(XCB_CONFIG_WINDOW_STACK_MODE));
    av_push(tags_all, newSVpvn("CONFIG_WINDOW_STACK_MODE", 24));
    newCONSTSUB(stash, "CONFIG_WINDOW_WIDTH", newSViv(XCB_CONFIG_WINDOW_WIDTH));
    av_push(tags_all, newSVpvn("CONFIG_WINDOW_WIDTH", 19));
    newCONSTSUB(stash, "CONFIG_WINDOW_X", newSViv(XCB_CONFIG_WINDOW_X));
    av_push(tags_all, newSVpvn("CONFIG_WINDOW_X", 15));
    newCONSTSUB(stash, "CONFIG_WINDOW_Y", newSViv(XCB_CONFIG_WINDOW_Y));
    av_push(tags_all, newSVpvn("CONFIG_WINDOW_Y", 15));
    newCONSTSUB(stash, "COORD_MODE_ORIGIN", newSViv(XCB_COORD_MODE_ORIGIN));
    av_push(tags_all, newSVpvn("COORD_MODE_ORIGIN", 17));
    newCONSTSUB(stash, "COORD_MODE_PREVIOUS", newSViv(XCB_COORD_MODE_PREVIOUS));
    av_push(tags_all, newSVpvn("COORD_MODE_PREVIOUS", 19));
    newCONSTSUB(stash, "CREATE_NOTIFY", newSViv(XCB_CREATE_NOTIFY));
    av_push(tags_all, newSVpvn("CREATE_NOTIFY", 13));
    newCONSTSUB(stash, "CURSOR_NONE", newSViv(XCB_CURSOR_NONE));
    av_push(tags_all, newSVpvn("CURSOR_NONE", 11));
    newCONSTSUB(stash, "CW_BACKING_PIXEL", newSViv(XCB_CW_BACKING_PIXEL));
    av_push(tags_all, newSVpvn("CW_BACKING_PIXEL", 16));
    newCONSTSUB(stash, "CW_BACKING_PLANES", newSViv(XCB_CW_BACKING_PLANES));
    av_push(tags_all, newSVpvn("CW_BACKING_PLANES", 17));
    newCONSTSUB(stash, "CW_BACKING_STORE", newSViv(XCB_CW_BACKING_STORE));
    av_push(tags_all, newSVpvn("CW_BACKING_STORE", 16));
    newCONSTSUB(stash, "CW_BACK_PIXEL", newSViv(XCB_CW_BACK_PIXEL));
    av_push(tags_all, newSVpvn("CW_BACK_PIXEL", 13));
    newCONSTSUB(stash, "CW_BACK_PIXMAP", newSViv(XCB_CW_BACK_PIXMAP));
    av_push(tags_all, newSVpvn("CW_BACK_PIXMAP", 14));
    newCONSTSUB(stash, "CW_BIT_GRAVITY", newSViv(XCB_CW_BIT_GRAVITY));
    av_push(tags_all, newSVpvn("CW_BIT_GRAVITY", 14));
    newCONSTSUB(stash, "CW_BORDER_PIXEL", newSViv(XCB_CW_BORDER_PIXEL));
    av_push(tags_all, newSVpvn("CW_BORDER_PIXEL", 15));
    newCONSTSUB(stash, "CW_BORDER_PIXMAP", newSViv(XCB_CW_BORDER_PIXMAP));
    av_push(tags_all, newSVpvn("CW_BORDER_PIXMAP", 16));
    newCONSTSUB(stash, "CW_COLORMAP", newSViv(XCB_CW_COLORMAP));
    av_push(tags_all, newSVpvn("CW_COLORMAP", 11));
    newCONSTSUB(stash, "CW_CURSOR", newSViv(XCB_CW_CURSOR));
    av_push(tags_all, newSVpvn("CW_CURSOR", 9));
    newCONSTSUB(stash, "CW_DONT_PROPAGATE", newSViv(XCB_CW_DONT_PROPAGATE));
    av_push(tags_all, newSVpvn("CW_DONT_PROPAGATE", 17));
    newCONSTSUB(stash, "CW_EVENT_MASK", newSViv(XCB_CW_EVENT_MASK));
    av_push(tags_all, newSVpvn("CW_EVENT_MASK", 13));
    newCONSTSUB(stash, "CW_OVERRIDE_REDIRECT", newSViv(XCB_CW_OVERRIDE_REDIRECT));
    av_push(tags_all, newSVpvn("CW_OVERRIDE_REDIRECT", 20));
    newCONSTSUB(stash, "CW_SAVE_UNDER", newSViv(XCB_CW_SAVE_UNDER));
    av_push(tags_all, newSVpvn("CW_SAVE_UNDER", 13));
    newCONSTSUB(stash, "CW_WIN_GRAVITY", newSViv(XCB_CW_WIN_GRAVITY));
    av_push(tags_all, newSVpvn("CW_WIN_GRAVITY", 14));
    newCONSTSUB(stash, "DESTROY_NOTIFY", newSViv(XCB_DESTROY_NOTIFY));
    av_push(tags_all, newSVpvn("DESTROY_NOTIFY", 14));
    newCONSTSUB(stash, "ENTER_NOTIFY", newSViv(XCB_ENTER_NOTIFY));
    av_push(tags_all, newSVpvn("ENTER_NOTIFY", 12));
    newCONSTSUB(stash, "EVENT_MASK_BUTTON_1_MOTION", newSViv(XCB_EVENT_MASK_BUTTON_1_MOTION));
    av_push(tags_all, newSVpvn("EVENT_MASK_BUTTON_1_MOTION", 26));
    newCONSTSUB(stash, "EVENT_MASK_BUTTON_2_MOTION", newSViv(XCB_EVENT_MASK_BUTTON_2_MOTION));
    av_push(tags_all, newSVpvn("EVENT_MASK_BUTTON_2_MOTION", 26));
    newCONSTSUB(stash, "EVENT_MASK_BUTTON_3_MOTION", newSViv(XCB_EVENT_MASK_BUTTON_3_MOTION));
    av_push(tags_all, newSVpvn("EVENT_MASK_BUTTON_3_MOTION", 26));
    newCONSTSUB(stash, "EVENT_MASK_BUTTON_4_MOTION", newSViv(XCB_EVENT_MASK_BUTTON_4_MOTION));
    av_push(tags_all, newSVpvn("EVENT_MASK_BUTTON_4_MOTION", 26));
    newCONSTSUB(stash, "EVENT_MASK_BUTTON_5_MOTION", newSViv(XCB_EVENT_MASK_BUTTON_5_MOTION));
    av_push(tags_all, newSVpvn("EVENT_MASK_BUTTON_5_MOTION", 26));
    newCONSTSUB(stash, "EVENT_MASK_BUTTON_MOTION", newSViv(XCB_EVENT_MASK_BUTTON_MOTION));
    av_push(tags_all, newSVpvn("EVENT_MASK_BUTTON_MOTION", 24));
    newCONSTSUB(stash, "EVENT_MASK_BUTTON_PRESS", newSViv(XCB_EVENT_MASK_BUTTON_PRESS));
    av_push(tags_all, newSVpvn("EVENT_MASK_BUTTON_PRESS", 23));
    newCONSTSUB(stash, "EVENT_MASK_BUTTON_RELEASE", newSViv(XCB_EVENT_MASK_BUTTON_RELEASE));
    av_push(tags_all, newSVpvn("EVENT_MASK_BUTTON_RELEASE", 25));
    newCONSTSUB(stash, "EVENT_MASK_COLOR_MAP_CHANGE", newSViv(XCB_EVENT_MASK_COLOR_MAP_CHANGE));
    av_push(tags_all, newSVpvn("EVENT_MASK_COLOR_MAP_CHANGE", 27));
    newCONSTSUB(stash, "EVENT_MASK_ENTER_WINDOW", newSViv(XCB_EVENT_MASK_ENTER_WINDOW));
    av_push(tags_all, newSVpvn("EVENT_MASK_ENTER_WINDOW", 23));
    newCONSTSUB(stash, "EVENT_MASK_EXPOSURE", newSViv(XCB_EVENT_MASK_EXPOSURE));
    av_push(tags_all, newSVpvn("EVENT_MASK_EXPOSURE", 19));
    newCONSTSUB(stash, "EVENT_MASK_FOCUS_CHANGE", newSViv(XCB_EVENT_MASK_FOCUS_CHANGE));
    av_push(tags_all, newSVpvn("EVENT_MASK_FOCUS_CHANGE", 23));
    newCONSTSUB(stash, "EVENT_MASK_KEYMAP_STATE", newSViv(XCB_EVENT_MASK_KEYMAP_STATE));
    av_push(tags_all, newSVpvn("EVENT_MASK_KEYMAP_STATE", 23));
    newCONSTSUB(stash, "EVENT_MASK_KEY_PRESS", newSViv(XCB_EVENT_MASK_KEY_PRESS));
    av_push(tags_all, newSVpvn("EVENT_MASK_KEY_PRESS", 20));
    newCONSTSUB(stash, "EVENT_MASK_KEY_RELEASE", newSViv(XCB_EVENT_MASK_KEY_RELEASE));
    av_push(tags_all, newSVpvn("EVENT_MASK_KEY_RELEASE", 22));
    newCONSTSUB(stash, "EVENT_MASK_LEAVE_WINDOW", newSViv(XCB_EVENT_MASK_LEAVE_WINDOW));
    av_push(tags_all, newSVpvn("EVENT_MASK_LEAVE_WINDOW", 23));
    newCONSTSUB(stash, "EVENT_MASK_NO_EVENT", newSViv(XCB_EVENT_MASK_NO_EVENT));
    av_push(tags_all, newSVpvn("EVENT_MASK_NO_EVENT", 19));
    newCONSTSUB(stash, "EVENT_MASK_OWNER_GRAB_BUTTON", newSViv(XCB_EVENT_MASK_OWNER_GRAB_BUTTON));
    av_push(tags_all, newSVpvn("EVENT_MASK_OWNER_GRAB_BUTTON", 28));
    newCONSTSUB(stash, "EVENT_MASK_POINTER_MOTION", newSViv(XCB_EVENT_MASK_POINTER_MOTION));
    av_push(tags_all, newSVpvn("EVENT_MASK_POINTER_MOTION", 25));
    newCONSTSUB(stash, "EVENT_MASK_POINTER_MOTION_HINT", newSViv(XCB_EVENT_MASK_POINTER_MOTION_HINT));
    av_push(tags_all, newSVpvn("EVENT_MASK_POINTER_MOTION_HINT", 30));
    newCONSTSUB(stash, "EVENT_MASK_PROPERTY_CHANGE", newSViv(XCB_EVENT_MASK_PROPERTY_CHANGE));
    av_push(tags_all, newSVpvn("EVENT_MASK_PROPERTY_CHANGE", 26));
    newCONSTSUB(stash, "EVENT_MASK_RESIZE_REDIRECT", newSViv(XCB_EVENT_MASK_RESIZE_REDIRECT));
    av_push(tags_all, newSVpvn("EVENT_MASK_RESIZE_REDIRECT", 26));
    newCONSTSUB(stash, "EVENT_MASK_STRUCTURE_NOTIFY", newSViv(XCB_EVENT_MASK_STRUCTURE_NOTIFY));
    av_push(tags_all, newSVpvn("EVENT_MASK_STRUCTURE_NOTIFY", 27));
    newCONSTSUB(stash, "EVENT_MASK_SUBSTRUCTURE_NOTIFY", newSViv(XCB_EVENT_MASK_SUBSTRUCTURE_NOTIFY));
    av_push(tags_all, newSVpvn("EVENT_MASK_SUBSTRUCTURE_NOTIFY", 30));
    newCONSTSUB(stash, "EVENT_MASK_SUBSTRUCTURE_REDIRECT", newSViv(XCB_EVENT_MASK_SUBSTRUCTURE_REDIRECT));
    av_push(tags_all, newSVpvn("EVENT_MASK_SUBSTRUCTURE_REDIRECT", 32));
    newCONSTSUB(stash, "EVENT_MASK_VISIBILITY_CHANGE", newSViv(XCB_EVENT_MASK_VISIBILITY_CHANGE));
    av_push(tags_all, newSVpvn("EVENT_MASK_VISIBILITY_CHANGE", 28));
    newCONSTSUB(stash, "EXPOSE", newSViv(XCB_EXPOSE));
    av_push(tags_all, newSVpvn("EXPOSE", 6));
    newCONSTSUB(stash, "EXPOSURES_ALLOWED", newSViv(XCB_EXPOSURES_ALLOWED));
    av_push(tags_all, newSVpvn("EXPOSURES_ALLOWED", 17));
    newCONSTSUB(stash, "EXPOSURES_DEFAULT", newSViv(XCB_EXPOSURES_DEFAULT));
    av_push(tags_all, newSVpvn("EXPOSURES_DEFAULT", 17));
    newCONSTSUB(stash, "EXPOSURES_NOT_ALLOWED", newSViv(XCB_EXPOSURES_NOT_ALLOWED));
    av_push(tags_all, newSVpvn("EXPOSURES_NOT_ALLOWED", 21));
    newCONSTSUB(stash, "FAMILY_CHAOS", newSViv(XCB_FAMILY_CHAOS));
    av_push(tags_all, newSVpvn("FAMILY_CHAOS", 12));
    newCONSTSUB(stash, "FAMILY_DECNET", newSViv(XCB_FAMILY_DECNET));
    av_push(tags_all, newSVpvn("FAMILY_DECNET", 13));
    newCONSTSUB(stash, "FAMILY_INTERNET", newSViv(XCB_FAMILY_INTERNET));
    av_push(tags_all, newSVpvn("FAMILY_INTERNET", 15));
    newCONSTSUB(stash, "FAMILY_INTERNET_6", newSViv(XCB_FAMILY_INTERNET_6));
    av_push(tags_all, newSVpvn("FAMILY_INTERNET_6", 17));
    newCONSTSUB(stash, "FAMILY_SERVER_INTERPRETED", newSViv(XCB_FAMILY_SERVER_INTERPRETED));
    av_push(tags_all, newSVpvn("FAMILY_SERVER_INTERPRETED", 25));
    newCONSTSUB(stash, "FILL_RULE_EVEN_ODD", newSViv(XCB_FILL_RULE_EVEN_ODD));
    av_push(tags_all, newSVpvn("FILL_RULE_EVEN_ODD", 18));
    newCONSTSUB(stash, "FILL_RULE_WINDING", newSViv(XCB_FILL_RULE_WINDING));
    av_push(tags_all, newSVpvn("FILL_RULE_WINDING", 17));
    newCONSTSUB(stash, "FILL_STYLE_OPAQUE_STIPPLED", newSViv(XCB_FILL_STYLE_OPAQUE_STIPPLED));
    av_push(tags_all, newSVpvn("FILL_STYLE_OPAQUE_STIPPLED", 26));
    newCONSTSUB(stash, "FILL_STYLE_SOLID", newSViv(XCB_FILL_STYLE_SOLID));
    av_push(tags_all, newSVpvn("FILL_STYLE_SOLID", 16));
    newCONSTSUB(stash, "FILL_STYLE_STIPPLED", newSViv(XCB_FILL_STYLE_STIPPLED));
    av_push(tags_all, newSVpvn("FILL_STYLE_STIPPLED", 19));
    newCONSTSUB(stash, "FILL_STYLE_TILED", newSViv(XCB_FILL_STYLE_TILED));
    av_push(tags_all, newSVpvn("FILL_STYLE_TILED", 16));
    newCONSTSUB(stash, "FOCUS_IN", newSViv(XCB_FOCUS_IN));
    av_push(tags_all, newSVpvn("FOCUS_IN", 8));
    newCONSTSUB(stash, "FONT_DRAW_LEFT_TO_RIGHT", newSViv(XCB_FONT_DRAW_LEFT_TO_RIGHT));
    av_push(tags_all, newSVpvn("FONT_DRAW_LEFT_TO_RIGHT", 23));
    newCONSTSUB(stash, "FONT_DRAW_RIGHT_TO_LEFT", newSViv(XCB_FONT_DRAW_RIGHT_TO_LEFT));
    av_push(tags_all, newSVpvn("FONT_DRAW_RIGHT_TO_LEFT", 23));
    newCONSTSUB(stash, "FONT_NONE", newSViv(XCB_FONT_NONE));
    av_push(tags_all, newSVpvn("FONT_NONE", 9));
    newCONSTSUB(stash, "GC_ARC_MODE", newSViv(XCB_GC_ARC_MODE));
    av_push(tags_all, newSVpvn("GC_ARC_MODE", 11));
    newCONSTSUB(stash, "GC_BACKGROUND", newSViv(XCB_GC_BACKGROUND));
    av_push(tags_all, newSVpvn("GC_BACKGROUND", 13));
    newCONSTSUB(stash, "GC_CAP_STYLE", newSViv(XCB_GC_CAP_STYLE));
    av_push(tags_all, newSVpvn("GC_CAP_STYLE", 12));
    newCONSTSUB(stash, "GC_CLIP_MASK", newSViv(XCB_GC_CLIP_MASK));
    av_push(tags_all, newSVpvn("GC_CLIP_MASK", 12));
    newCONSTSUB(stash, "GC_CLIP_ORIGIN_X", newSViv(XCB_GC_CLIP_ORIGIN_X));
    av_push(tags_all, newSVpvn("GC_CLIP_ORIGIN_X", 16));
    newCONSTSUB(stash, "GC_CLIP_ORIGIN_Y", newSViv(XCB_GC_CLIP_ORIGIN_Y));
    av_push(tags_all, newSVpvn("GC_CLIP_ORIGIN_Y", 16));
    newCONSTSUB(stash, "GC_DASH_LIST", newSViv(XCB_GC_DASH_LIST));
    av_push(tags_all, newSVpvn("GC_DASH_LIST", 12));
    newCONSTSUB(stash, "GC_DASH_OFFSET", newSViv(XCB_GC_DASH_OFFSET));
    av_push(tags_all, newSVpvn("GC_DASH_OFFSET", 14));
    newCONSTSUB(stash, "GC_FILL_RULE", newSViv(XCB_GC_FILL_RULE));
    av_push(tags_all, newSVpvn("GC_FILL_RULE", 12));
    newCONSTSUB(stash, "GC_FILL_STYLE", newSViv(XCB_GC_FILL_STYLE));
    av_push(tags_all, newSVpvn("GC_FILL_STYLE", 13));
    newCONSTSUB(stash, "GC_FONT", newSViv(XCB_GC_FONT));
    av_push(tags_all, newSVpvn("GC_FONT", 7));
    newCONSTSUB(stash, "GC_FOREGROUND", newSViv(XCB_GC_FOREGROUND));
    av_push(tags_all, newSVpvn("GC_FOREGROUND", 13));
    newCONSTSUB(stash, "GC_FUNCTION", newSViv(XCB_GC_FUNCTION));
    av_push(tags_all, newSVpvn("GC_FUNCTION", 11));
    newCONSTSUB(stash, "GC_GRAPHICS_EXPOSURES", newSViv(XCB_GC_GRAPHICS_EXPOSURES));
    av_push(tags_all, newSVpvn("GC_GRAPHICS_EXPOSURES", 21));
    newCONSTSUB(stash, "GC_JOIN_STYLE", newSViv(XCB_GC_JOIN_STYLE));
    av_push(tags_all, newSVpvn("GC_JOIN_STYLE", 13));
    newCONSTSUB(stash, "GC_LINE_STYLE", newSViv(XCB_GC_LINE_STYLE));
    av_push(tags_all, newSVpvn("GC_LINE_STYLE", 13));
    newCONSTSUB(stash, "GC_LINE_WIDTH", newSViv(XCB_GC_LINE_WIDTH));
    av_push(tags_all, newSVpvn("GC_LINE_WIDTH", 13));
    newCONSTSUB(stash, "GC_PLANE_MASK", newSViv(XCB_GC_PLANE_MASK));
    av_push(tags_all, newSVpvn("GC_PLANE_MASK", 13));
    newCONSTSUB(stash, "GC_STIPPLE", newSViv(XCB_GC_STIPPLE));
    av_push(tags_all, newSVpvn("GC_STIPPLE", 10));
    newCONSTSUB(stash, "GC_SUBWINDOW_MODE", newSViv(XCB_GC_SUBWINDOW_MODE));
    av_push(tags_all, newSVpvn("GC_SUBWINDOW_MODE", 17));
    newCONSTSUB(stash, "GC_TILE", newSViv(XCB_GC_TILE));
    av_push(tags_all, newSVpvn("GC_TILE", 7));
    newCONSTSUB(stash, "GC_TILE_STIPPLE_ORIGIN_X", newSViv(XCB_GC_TILE_STIPPLE_ORIGIN_X));
    av_push(tags_all, newSVpvn("GC_TILE_STIPPLE_ORIGIN_X", 24));
    newCONSTSUB(stash, "GC_TILE_STIPPLE_ORIGIN_Y", newSViv(XCB_GC_TILE_STIPPLE_ORIGIN_Y));
    av_push(tags_all, newSVpvn("GC_TILE_STIPPLE_ORIGIN_Y", 24));
    newCONSTSUB(stash, "GET_PROPERTY_TYPE_ANY", newSViv(XCB_GET_PROPERTY_TYPE_ANY));
    av_push(tags_all, newSVpvn("GET_PROPERTY_TYPE_ANY", 21));
    newCONSTSUB(stash, "GRAB_ANY", newSViv(XCB_GRAB_ANY));
    av_push(tags_all, newSVpvn("GRAB_ANY", 8));
    newCONSTSUB(stash, "GRAB_MODE_ASYNC", newSViv(XCB_GRAB_MODE_ASYNC));
    av_push(tags_all, newSVpvn("GRAB_MODE_ASYNC", 15));
    newCONSTSUB(stash, "GRAB_MODE_SYNC", newSViv(XCB_GRAB_MODE_SYNC));
    av_push(tags_all, newSVpvn("GRAB_MODE_SYNC", 14));
    newCONSTSUB(stash, "GRAB_STATUS_ALREADY_GRABBED", newSViv(XCB_GRAB_STATUS_ALREADY_GRABBED));
    av_push(tags_all, newSVpvn("GRAB_STATUS_ALREADY_GRABBED", 27));
    newCONSTSUB(stash, "GRAB_STATUS_FROZEN", newSViv(XCB_GRAB_STATUS_FROZEN));
    av_push(tags_all, newSVpvn("GRAB_STATUS_FROZEN", 18));
    newCONSTSUB(stash, "GRAB_STATUS_INVALID_TIME", newSViv(XCB_GRAB_STATUS_INVALID_TIME));
    av_push(tags_all, newSVpvn("GRAB_STATUS_INVALID_TIME", 24));
    newCONSTSUB(stash, "GRAB_STATUS_NOT_VIEWABLE", newSViv(XCB_GRAB_STATUS_NOT_VIEWABLE));
    av_push(tags_all, newSVpvn("GRAB_STATUS_NOT_VIEWABLE", 24));
    newCONSTSUB(stash, "GRAB_STATUS_SUCCESS", newSViv(XCB_GRAB_STATUS_SUCCESS));
    av_push(tags_all, newSVpvn("GRAB_STATUS_SUCCESS", 19));
    newCONSTSUB(stash, "GRAPHICS_EXPOSURE", newSViv(XCB_GRAPHICS_EXPOSURE));
    av_push(tags_all, newSVpvn("GRAPHICS_EXPOSURE", 17));
    newCONSTSUB(stash, "GRAVITY_BIT_FORGET", newSViv(XCB_GRAVITY_BIT_FORGET));
    av_push(tags_all, newSVpvn("GRAVITY_BIT_FORGET", 18));
    newCONSTSUB(stash, "GRAVITY_CENTER", newSViv(XCB_GRAVITY_CENTER));
    av_push(tags_all, newSVpvn("GRAVITY_CENTER", 14));
    newCONSTSUB(stash, "GRAVITY_EAST", newSViv(XCB_GRAVITY_EAST));
    av_push(tags_all, newSVpvn("GRAVITY_EAST", 12));
    newCONSTSUB(stash, "GRAVITY_NORTH", newSViv(XCB_GRAVITY_NORTH));
    av_push(tags_all, newSVpvn("GRAVITY_NORTH", 13));
    newCONSTSUB(stash, "GRAVITY_NORTH_EAST", newSViv(XCB_GRAVITY_NORTH_EAST));
    av_push(tags_all, newSVpvn("GRAVITY_NORTH_EAST", 18));
    newCONSTSUB(stash, "GRAVITY_NORTH_WEST", newSViv(XCB_GRAVITY_NORTH_WEST));
    av_push(tags_all, newSVpvn("GRAVITY_NORTH_WEST", 18));
    newCONSTSUB(stash, "GRAVITY_NOTIFY", newSViv(XCB_GRAVITY_NOTIFY));
    av_push(tags_all, newSVpvn("GRAVITY_NOTIFY", 14));
    newCONSTSUB(stash, "GRAVITY_SOUTH", newSViv(XCB_GRAVITY_SOUTH));
    av_push(tags_all, newSVpvn("GRAVITY_SOUTH", 13));
    newCONSTSUB(stash, "GRAVITY_SOUTH_EAST", newSViv(XCB_GRAVITY_SOUTH_EAST));
    av_push(tags_all, newSVpvn("GRAVITY_SOUTH_EAST", 18));
    newCONSTSUB(stash, "GRAVITY_SOUTH_WEST", newSViv(XCB_GRAVITY_SOUTH_WEST));
    av_push(tags_all, newSVpvn("GRAVITY_SOUTH_WEST", 18));
    newCONSTSUB(stash, "GRAVITY_STATIC", newSViv(XCB_GRAVITY_STATIC));
    av_push(tags_all, newSVpvn("GRAVITY_STATIC", 14));
    newCONSTSUB(stash, "GRAVITY_WEST", newSViv(XCB_GRAVITY_WEST));
    av_push(tags_all, newSVpvn("GRAVITY_WEST", 12));
    newCONSTSUB(stash, "GRAVITY_WIN_UNMAP", newSViv(XCB_GRAVITY_WIN_UNMAP));
    av_push(tags_all, newSVpvn("GRAVITY_WIN_UNMAP", 17));
    newCONSTSUB(stash, "GX_AND", newSViv(XCB_GX_AND));
    av_push(tags_all, newSVpvn("GX_AND", 6));
    newCONSTSUB(stash, "GX_AND_INVERTED", newSViv(XCB_GX_AND_INVERTED));
    av_push(tags_all, newSVpvn("GX_AND_INVERTED", 15));
    newCONSTSUB(stash, "GX_AND_REVERSE", newSViv(XCB_GX_AND_REVERSE));
    av_push(tags_all, newSVpvn("GX_AND_REVERSE", 14));
    newCONSTSUB(stash, "GX_CLEAR", newSViv(XCB_GX_CLEAR));
    av_push(tags_all, newSVpvn("GX_CLEAR", 8));
    newCONSTSUB(stash, "GX_COPY", newSViv(XCB_GX_COPY));
    av_push(tags_all, newSVpvn("GX_COPY", 7));
    newCONSTSUB(stash, "GX_COPY_INVERTED", newSViv(XCB_GX_COPY_INVERTED));
    av_push(tags_all, newSVpvn("GX_COPY_INVERTED", 16));
    newCONSTSUB(stash, "GX_EQUIV", newSViv(XCB_GX_EQUIV));
    av_push(tags_all, newSVpvn("GX_EQUIV", 8));
    newCONSTSUB(stash, "GX_INVERT", newSViv(XCB_GX_INVERT));
    av_push(tags_all, newSVpvn("GX_INVERT", 9));
    newCONSTSUB(stash, "GX_NAND", newSViv(XCB_GX_NAND));
    av_push(tags_all, newSVpvn("GX_NAND", 7));
    newCONSTSUB(stash, "GX_NOOP", newSViv(XCB_GX_NOOP));
    av_push(tags_all, newSVpvn("GX_NOOP", 7));
    newCONSTSUB(stash, "GX_NOR", newSViv(XCB_GX_NOR));
    av_push(tags_all, newSVpvn("GX_NOR", 6));
    newCONSTSUB(stash, "GX_OR", newSViv(XCB_GX_OR));
    av_push(tags_all, newSVpvn("GX_OR", 5));
    newCONSTSUB(stash, "GX_OR_INVERTED", newSViv(XCB_GX_OR_INVERTED));
    av_push(tags_all, newSVpvn("GX_OR_INVERTED", 14));
    newCONSTSUB(stash, "GX_OR_REVERSE", newSViv(XCB_GX_OR_REVERSE));
    av_push(tags_all, newSVpvn("GX_OR_REVERSE", 13));
    newCONSTSUB(stash, "GX_SET", newSViv(XCB_GX_SET));
    av_push(tags_all, newSVpvn("GX_SET", 6));
    newCONSTSUB(stash, "GX_XOR", newSViv(XCB_GX_XOR));
    av_push(tags_all, newSVpvn("GX_XOR", 6));
    newCONSTSUB(stash, "HOST_MODE_DELETE", newSViv(XCB_HOST_MODE_DELETE));
    av_push(tags_all, newSVpvn("HOST_MODE_DELETE", 16));
    newCONSTSUB(stash, "HOST_MODE_INSERT", newSViv(XCB_HOST_MODE_INSERT));
    av_push(tags_all, newSVpvn("HOST_MODE_INSERT", 16));
    newCONSTSUB(stash, "ICCCM_WM_STATE_ICONIC", newSViv(XCB_ICCCM_WM_STATE_ICONIC));
    av_push(tags_all, newSVpvn("ICCCM_WM_STATE_ICONIC", 21));
    newCONSTSUB(stash, "ICCCM_WM_STATE_NORMAL", newSViv(XCB_ICCCM_WM_STATE_NORMAL));
    av_push(tags_all, newSVpvn("ICCCM_WM_STATE_NORMAL", 21));
    newCONSTSUB(stash, "ICCCM_WM_STATE_WITHDRAWN", newSViv(XCB_ICCCM_WM_STATE_WITHDRAWN));
    av_push(tags_all, newSVpvn("ICCCM_WM_STATE_WITHDRAWN", 24));
    newCONSTSUB(stash, "IMAGE_FORMAT_XY_BITMAP", newSViv(XCB_IMAGE_FORMAT_XY_BITMAP));
    av_push(tags_all, newSVpvn("IMAGE_FORMAT_XY_BITMAP", 22));
    newCONSTSUB(stash, "IMAGE_FORMAT_XY_PIXMAP", newSViv(XCB_IMAGE_FORMAT_XY_PIXMAP));
    av_push(tags_all, newSVpvn("IMAGE_FORMAT_XY_PIXMAP", 22));
    newCONSTSUB(stash, "IMAGE_FORMAT_Z_PIXMAP", newSViv(XCB_IMAGE_FORMAT_Z_PIXMAP));
    av_push(tags_all, newSVpvn("IMAGE_FORMAT_Z_PIXMAP", 21));
    newCONSTSUB(stash, "IMAGE_ORDER_LSB_FIRST", newSViv(XCB_IMAGE_ORDER_LSB_FIRST));
    av_push(tags_all, newSVpvn("IMAGE_ORDER_LSB_FIRST", 21));
    newCONSTSUB(stash, "IMAGE_ORDER_MSB_FIRST", newSViv(XCB_IMAGE_ORDER_MSB_FIRST));
    av_push(tags_all, newSVpvn("IMAGE_ORDER_MSB_FIRST", 21));
    newCONSTSUB(stash, "INPUT_FOCUS_FOLLOW_KEYBOARD", newSViv(XCB_INPUT_FOCUS_FOLLOW_KEYBOARD));
    av_push(tags_all, newSVpvn("INPUT_FOCUS_FOLLOW_KEYBOARD", 27));
    newCONSTSUB(stash, "INPUT_FOCUS_NONE", newSViv(XCB_INPUT_FOCUS_NONE));
    av_push(tags_all, newSVpvn("INPUT_FOCUS_NONE", 16));
    newCONSTSUB(stash, "INPUT_FOCUS_PARENT", newSViv(XCB_INPUT_FOCUS_PARENT));
    av_push(tags_all, newSVpvn("INPUT_FOCUS_PARENT", 18));
    newCONSTSUB(stash, "INPUT_FOCUS_POINTER_ROOT", newSViv(XCB_INPUT_FOCUS_POINTER_ROOT));
    av_push(tags_all, newSVpvn("INPUT_FOCUS_POINTER_ROOT", 24));
    newCONSTSUB(stash, "JOIN_STYLE_BEVEL", newSViv(XCB_JOIN_STYLE_BEVEL));
    av_push(tags_all, newSVpvn("JOIN_STYLE_BEVEL", 16));
    newCONSTSUB(stash, "JOIN_STYLE_MITER", newSViv(XCB_JOIN_STYLE_MITER));
    av_push(tags_all, newSVpvn("JOIN_STYLE_MITER", 16));
    newCONSTSUB(stash, "JOIN_STYLE_ROUND", newSViv(XCB_JOIN_STYLE_ROUND));
    av_push(tags_all, newSVpvn("JOIN_STYLE_ROUND", 16));
    newCONSTSUB(stash, "KB_AUTO_REPEAT_MODE", newSViv(XCB_KB_AUTO_REPEAT_MODE));
    av_push(tags_all, newSVpvn("KB_AUTO_REPEAT_MODE", 19));
    newCONSTSUB(stash, "KB_BELL_DURATION", newSViv(XCB_KB_BELL_DURATION));
    av_push(tags_all, newSVpvn("KB_BELL_DURATION", 16));
    newCONSTSUB(stash, "KB_BELL_PERCENT", newSViv(XCB_KB_BELL_PERCENT));
    av_push(tags_all, newSVpvn("KB_BELL_PERCENT", 15));
    newCONSTSUB(stash, "KB_BELL_PITCH", newSViv(XCB_KB_BELL_PITCH));
    av_push(tags_all, newSVpvn("KB_BELL_PITCH", 13));
    newCONSTSUB(stash, "KB_KEY", newSViv(XCB_KB_KEY));
    av_push(tags_all, newSVpvn("KB_KEY", 6));
    newCONSTSUB(stash, "KB_KEY_CLICK_PERCENT", newSViv(XCB_KB_KEY_CLICK_PERCENT));
    av_push(tags_all, newSVpvn("KB_KEY_CLICK_PERCENT", 20));
    newCONSTSUB(stash, "KB_LED", newSViv(XCB_KB_LED));
    av_push(tags_all, newSVpvn("KB_LED", 6));
    newCONSTSUB(stash, "KB_LED_MODE", newSViv(XCB_KB_LED_MODE));
    av_push(tags_all, newSVpvn("KB_LED_MODE", 11));
    newCONSTSUB(stash, "KEYMAP_NOTIFY", newSViv(XCB_KEYMAP_NOTIFY));
    av_push(tags_all, newSVpvn("KEYMAP_NOTIFY", 13));
    newCONSTSUB(stash, "KEY_BUT_MASK_BUTTON_1", newSViv(XCB_KEY_BUT_MASK_BUTTON_1));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_BUTTON_1", 21));
    newCONSTSUB(stash, "KEY_BUT_MASK_BUTTON_2", newSViv(XCB_KEY_BUT_MASK_BUTTON_2));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_BUTTON_2", 21));
    newCONSTSUB(stash, "KEY_BUT_MASK_BUTTON_3", newSViv(XCB_KEY_BUT_MASK_BUTTON_3));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_BUTTON_3", 21));
    newCONSTSUB(stash, "KEY_BUT_MASK_BUTTON_4", newSViv(XCB_KEY_BUT_MASK_BUTTON_4));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_BUTTON_4", 21));
    newCONSTSUB(stash, "KEY_BUT_MASK_BUTTON_5", newSViv(XCB_KEY_BUT_MASK_BUTTON_5));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_BUTTON_5", 21));
    newCONSTSUB(stash, "KEY_BUT_MASK_CONTROL", newSViv(XCB_KEY_BUT_MASK_CONTROL));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_CONTROL", 20));
    newCONSTSUB(stash, "KEY_BUT_MASK_LOCK", newSViv(XCB_KEY_BUT_MASK_LOCK));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_LOCK", 17));
    newCONSTSUB(stash, "KEY_BUT_MASK_MOD_1", newSViv(XCB_KEY_BUT_MASK_MOD_1));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_MOD_1", 18));
    newCONSTSUB(stash, "KEY_BUT_MASK_MOD_2", newSViv(XCB_KEY_BUT_MASK_MOD_2));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_MOD_2", 18));
    newCONSTSUB(stash, "KEY_BUT_MASK_MOD_3", newSViv(XCB_KEY_BUT_MASK_MOD_3));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_MOD_3", 18));
    newCONSTSUB(stash, "KEY_BUT_MASK_MOD_4", newSViv(XCB_KEY_BUT_MASK_MOD_4));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_MOD_4", 18));
    newCONSTSUB(stash, "KEY_BUT_MASK_MOD_5", newSViv(XCB_KEY_BUT_MASK_MOD_5));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_MOD_5", 18));
    newCONSTSUB(stash, "KEY_BUT_MASK_SHIFT", newSViv(XCB_KEY_BUT_MASK_SHIFT));
    av_push(tags_all, newSVpvn("KEY_BUT_MASK_SHIFT", 18));
    newCONSTSUB(stash, "KEY_PRESS", newSViv(XCB_KEY_PRESS));
    av_push(tags_all, newSVpvn("KEY_PRESS", 9));
    newCONSTSUB(stash, "KILL_ALL_TEMPORARY", newSViv(XCB_KILL_ALL_TEMPORARY));
    av_push(tags_all, newSVpvn("KILL_ALL_TEMPORARY", 18));
    newCONSTSUB(stash, "LED_MODE_OFF", newSViv(XCB_LED_MODE_OFF));
    av_push(tags_all, newSVpvn("LED_MODE_OFF", 12));
    newCONSTSUB(stash, "LED_MODE_ON", newSViv(XCB_LED_MODE_ON));
    av_push(tags_all, newSVpvn("LED_MODE_ON", 11));
    newCONSTSUB(stash, "LINE_STYLE_DOUBLE_DASH", newSViv(XCB_LINE_STYLE_DOUBLE_DASH));
    av_push(tags_all, newSVpvn("LINE_STYLE_DOUBLE_DASH", 22));
    newCONSTSUB(stash, "LINE_STYLE_ON_OFF_DASH", newSViv(XCB_LINE_STYLE_ON_OFF_DASH));
    av_push(tags_all, newSVpvn("LINE_STYLE_ON_OFF_DASH", 22));
    newCONSTSUB(stash, "LINE_STYLE_SOLID", newSViv(XCB_LINE_STYLE_SOLID));
    av_push(tags_all, newSVpvn("LINE_STYLE_SOLID", 16));
    newCONSTSUB(stash, "MAPPING_KEYBOARD", newSViv(XCB_MAPPING_KEYBOARD));
    av_push(tags_all, newSVpvn("MAPPING_KEYBOARD", 16));
    newCONSTSUB(stash, "MAPPING_MODIFIER", newSViv(XCB_MAPPING_MODIFIER));
    av_push(tags_all, newSVpvn("MAPPING_MODIFIER", 16));
    newCONSTSUB(stash, "MAPPING_NOTIFY", newSViv(XCB_MAPPING_NOTIFY));
    av_push(tags_all, newSVpvn("MAPPING_NOTIFY", 14));
    newCONSTSUB(stash, "MAPPING_POINTER", newSViv(XCB_MAPPING_POINTER));
    av_push(tags_all, newSVpvn("MAPPING_POINTER", 15));
    newCONSTSUB(stash, "MAPPING_STATUS_BUSY", newSViv(XCB_MAPPING_STATUS_BUSY));
    av_push(tags_all, newSVpvn("MAPPING_STATUS_BUSY", 19));
    newCONSTSUB(stash, "MAPPING_STATUS_FAILURE", newSViv(XCB_MAPPING_STATUS_FAILURE));
    av_push(tags_all, newSVpvn("MAPPING_STATUS_FAILURE", 22));
    newCONSTSUB(stash, "MAPPING_STATUS_SUCCESS", newSViv(XCB_MAPPING_STATUS_SUCCESS));
    av_push(tags_all, newSVpvn("MAPPING_STATUS_SUCCESS", 22));
    newCONSTSUB(stash, "MAP_INDEX_1", newSViv(XCB_MAP_INDEX_1));
    av_push(tags_all, newSVpvn("MAP_INDEX_1", 11));
    newCONSTSUB(stash, "MAP_INDEX_2", newSViv(XCB_MAP_INDEX_2));
    av_push(tags_all, newSVpvn("MAP_INDEX_2", 11));
    newCONSTSUB(stash, "MAP_INDEX_3", newSViv(XCB_MAP_INDEX_3));
    av_push(tags_all, newSVpvn("MAP_INDEX_3", 11));
    newCONSTSUB(stash, "MAP_INDEX_4", newSViv(XCB_MAP_INDEX_4));
    av_push(tags_all, newSVpvn("MAP_INDEX_4", 11));
    newCONSTSUB(stash, "MAP_INDEX_5", newSViv(XCB_MAP_INDEX_5));
    av_push(tags_all, newSVpvn("MAP_INDEX_5", 11));
    newCONSTSUB(stash, "MAP_INDEX_CONTROL", newSViv(XCB_MAP_INDEX_CONTROL));
    av_push(tags_all, newSVpvn("MAP_INDEX_CONTROL", 17));
    newCONSTSUB(stash, "MAP_INDEX_LOCK", newSViv(XCB_MAP_INDEX_LOCK));
    av_push(tags_all, newSVpvn("MAP_INDEX_LOCK", 14));
    newCONSTSUB(stash, "MAP_INDEX_SHIFT", newSViv(XCB_MAP_INDEX_SHIFT));
    av_push(tags_all, newSVpvn("MAP_INDEX_SHIFT", 15));
    newCONSTSUB(stash, "MAP_NOTIFY", newSViv(XCB_MAP_NOTIFY));
    av_push(tags_all, newSVpvn("MAP_NOTIFY", 10));
    newCONSTSUB(stash, "MAP_REQUEST", newSViv(XCB_MAP_REQUEST));
    av_push(tags_all, newSVpvn("MAP_REQUEST", 11));
    newCONSTSUB(stash, "MAP_STATE_UNMAPPED", newSViv(XCB_MAP_STATE_UNMAPPED));
    av_push(tags_all, newSVpvn("MAP_STATE_UNMAPPED", 18));
    newCONSTSUB(stash, "MAP_STATE_UNVIEWABLE", newSViv(XCB_MAP_STATE_UNVIEWABLE));
    av_push(tags_all, newSVpvn("MAP_STATE_UNVIEWABLE", 20));
    newCONSTSUB(stash, "MAP_STATE_VIEWABLE", newSViv(XCB_MAP_STATE_VIEWABLE));
    av_push(tags_all, newSVpvn("MAP_STATE_VIEWABLE", 18));
    newCONSTSUB(stash, "MOD_MASK_1", newSViv(XCB_MOD_MASK_1));
    av_push(tags_all, newSVpvn("MOD_MASK_1", 10));
    newCONSTSUB(stash, "MOD_MASK_2", newSViv(XCB_MOD_MASK_2));
    av_push(tags_all, newSVpvn("MOD_MASK_2", 10));
    newCONSTSUB(stash, "MOD_MASK_3", newSViv(XCB_MOD_MASK_3));
    av_push(tags_all, newSVpvn("MOD_MASK_3", 10));
    newCONSTSUB(stash, "MOD_MASK_4", newSViv(XCB_MOD_MASK_4));
    av_push(tags_all, newSVpvn("MOD_MASK_4", 10));
    newCONSTSUB(stash, "MOD_MASK_5", newSViv(XCB_MOD_MASK_5));
    av_push(tags_all, newSVpvn("MOD_MASK_5", 10));
    newCONSTSUB(stash, "MOD_MASK_ANY", newSViv(XCB_MOD_MASK_ANY));
    av_push(tags_all, newSVpvn("MOD_MASK_ANY", 12));
    newCONSTSUB(stash, "MOD_MASK_CONTROL", newSViv(XCB_MOD_MASK_CONTROL));
    av_push(tags_all, newSVpvn("MOD_MASK_CONTROL", 16));
    newCONSTSUB(stash, "MOD_MASK_LOCK", newSViv(XCB_MOD_MASK_LOCK));
    av_push(tags_all, newSVpvn("MOD_MASK_LOCK", 13));
    newCONSTSUB(stash, "MOD_MASK_SHIFT", newSViv(XCB_MOD_MASK_SHIFT));
    av_push(tags_all, newSVpvn("MOD_MASK_SHIFT", 14));
    newCONSTSUB(stash, "MOTION_HINT", newSViv(XCB_MOTION_HINT));
    av_push(tags_all, newSVpvn("MOTION_HINT", 11));
    newCONSTSUB(stash, "MOTION_NORMAL", newSViv(XCB_MOTION_NORMAL));
    av_push(tags_all, newSVpvn("MOTION_NORMAL", 13));
    newCONSTSUB(stash, "MOTION_NOTIFY", newSViv(XCB_MOTION_NOTIFY));
    av_push(tags_all, newSVpvn("MOTION_NOTIFY", 13));
    newCONSTSUB(stash, "NOTIFY_DETAIL_ANCESTOR", newSViv(XCB_NOTIFY_DETAIL_ANCESTOR));
    av_push(tags_all, newSVpvn("NOTIFY_DETAIL_ANCESTOR", 22));
    newCONSTSUB(stash, "NOTIFY_DETAIL_INFERIOR", newSViv(XCB_NOTIFY_DETAIL_INFERIOR));
    av_push(tags_all, newSVpvn("NOTIFY_DETAIL_INFERIOR", 22));
    newCONSTSUB(stash, "NOTIFY_DETAIL_NONE", newSViv(XCB_NOTIFY_DETAIL_NONE));
    av_push(tags_all, newSVpvn("NOTIFY_DETAIL_NONE", 18));
    newCONSTSUB(stash, "NOTIFY_DETAIL_NONLINEAR", newSViv(XCB_NOTIFY_DETAIL_NONLINEAR));
    av_push(tags_all, newSVpvn("NOTIFY_DETAIL_NONLINEAR", 23));
    newCONSTSUB(stash, "NOTIFY_DETAIL_NONLINEAR_VIRTUAL", newSViv(XCB_NOTIFY_DETAIL_NONLINEAR_VIRTUAL));
    av_push(tags_all, newSVpvn("NOTIFY_DETAIL_NONLINEAR_VIRTUAL", 31));
    newCONSTSUB(stash, "NOTIFY_DETAIL_POINTER", newSViv(XCB_NOTIFY_DETAIL_POINTER));
    av_push(tags_all, newSVpvn("NOTIFY_DETAIL_POINTER", 21));
    newCONSTSUB(stash, "NOTIFY_DETAIL_POINTER_ROOT", newSViv(XCB_NOTIFY_DETAIL_POINTER_ROOT));
    av_push(tags_all, newSVpvn("NOTIFY_DETAIL_POINTER_ROOT", 26));
    newCONSTSUB(stash, "NOTIFY_DETAIL_VIRTUAL", newSViv(XCB_NOTIFY_DETAIL_VIRTUAL));
    av_push(tags_all, newSVpvn("NOTIFY_DETAIL_VIRTUAL", 21));
    newCONSTSUB(stash, "NOTIFY_MODE_GRAB", newSViv(XCB_NOTIFY_MODE_GRAB));
    av_push(tags_all, newSVpvn("NOTIFY_MODE_GRAB", 16));
    newCONSTSUB(stash, "NOTIFY_MODE_NORMAL", newSViv(XCB_NOTIFY_MODE_NORMAL));
    av_push(tags_all, newSVpvn("NOTIFY_MODE_NORMAL", 18));
    newCONSTSUB(stash, "NOTIFY_MODE_UNGRAB", newSViv(XCB_NOTIFY_MODE_UNGRAB));
    av_push(tags_all, newSVpvn("NOTIFY_MODE_UNGRAB", 18));
    newCONSTSUB(stash, "NOTIFY_MODE_WHILE_GRABBED", newSViv(XCB_NOTIFY_MODE_WHILE_GRABBED));
    av_push(tags_all, newSVpvn("NOTIFY_MODE_WHILE_GRABBED", 25));
    newCONSTSUB(stash, "NO_EXPOSURE", newSViv(XCB_NO_EXPOSURE));
    av_push(tags_all, newSVpvn("NO_EXPOSURE", 11));
    newCONSTSUB(stash, "PIXMAP_NONE", newSViv(XCB_PIXMAP_NONE));
    av_push(tags_all, newSVpvn("PIXMAP_NONE", 11));
    newCONSTSUB(stash, "PLACE_ON_BOTTOM", newSViv(XCB_PLACE_ON_BOTTOM));
    av_push(tags_all, newSVpvn("PLACE_ON_BOTTOM", 15));
    newCONSTSUB(stash, "PLACE_ON_TOP", newSViv(XCB_PLACE_ON_TOP));
    av_push(tags_all, newSVpvn("PLACE_ON_TOP", 12));
    newCONSTSUB(stash, "POLY_SHAPE_COMPLEX", newSViv(XCB_POLY_SHAPE_COMPLEX));
    av_push(tags_all, newSVpvn("POLY_SHAPE_COMPLEX", 18));
    newCONSTSUB(stash, "POLY_SHAPE_CONVEX", newSViv(XCB_POLY_SHAPE_CONVEX));
    av_push(tags_all, newSVpvn("POLY_SHAPE_CONVEX", 17));
    newCONSTSUB(stash, "POLY_SHAPE_NONCONVEX", newSViv(XCB_POLY_SHAPE_NONCONVEX));
    av_push(tags_all, newSVpvn("POLY_SHAPE_NONCONVEX", 20));
    newCONSTSUB(stash, "PROPERTY_DELETE", newSViv(XCB_PROPERTY_DELETE));
    av_push(tags_all, newSVpvn("PROPERTY_DELETE", 15));
    newCONSTSUB(stash, "PROPERTY_NEW_VALUE", newSViv(XCB_PROPERTY_NEW_VALUE));
    av_push(tags_all, newSVpvn("PROPERTY_NEW_VALUE", 18));
    newCONSTSUB(stash, "PROPERTY_NOTIFY", newSViv(XCB_PROPERTY_NOTIFY));
    av_push(tags_all, newSVpvn("PROPERTY_NOTIFY", 15));
    newCONSTSUB(stash, "PROP_MODE_APPEND", newSViv(XCB_PROP_MODE_APPEND));
    av_push(tags_all, newSVpvn("PROP_MODE_APPEND", 16));
    newCONSTSUB(stash, "PROP_MODE_PREPEND", newSViv(XCB_PROP_MODE_PREPEND));
    av_push(tags_all, newSVpvn("PROP_MODE_PREPEND", 17));
    newCONSTSUB(stash, "PROP_MODE_REPLACE", newSViv(XCB_PROP_MODE_REPLACE));
    av_push(tags_all, newSVpvn("PROP_MODE_REPLACE", 17));
    newCONSTSUB(stash, "QUERY_SHAPE_OF_FASTEST_STIPPLE", newSViv(XCB_QUERY_SHAPE_OF_FASTEST_STIPPLE));
    av_push(tags_all, newSVpvn("QUERY_SHAPE_OF_FASTEST_STIPPLE", 30));
    newCONSTSUB(stash, "QUERY_SHAPE_OF_FASTEST_TILE", newSViv(XCB_QUERY_SHAPE_OF_FASTEST_TILE));
    av_push(tags_all, newSVpvn("QUERY_SHAPE_OF_FASTEST_TILE", 27));
    newCONSTSUB(stash, "QUERY_SHAPE_OF_LARGEST_CURSOR", newSViv(XCB_QUERY_SHAPE_OF_LARGEST_CURSOR));
    av_push(tags_all, newSVpvn("QUERY_SHAPE_OF_LARGEST_CURSOR", 29));
    newCONSTSUB(stash, "REPARENT_NOTIFY", newSViv(XCB_REPARENT_NOTIFY));
    av_push(tags_all, newSVpvn("REPARENT_NOTIFY", 15));
    newCONSTSUB(stash, "RESIZE_REQUEST", newSViv(XCB_RESIZE_REQUEST));
    av_push(tags_all, newSVpvn("RESIZE_REQUEST", 14));
    newCONSTSUB(stash, "SCREEN_SAVER_ACTIVE", newSViv(XCB_SCREEN_SAVER_ACTIVE));
    av_push(tags_all, newSVpvn("SCREEN_SAVER_ACTIVE", 19));
    newCONSTSUB(stash, "SCREEN_SAVER_RESET", newSViv(XCB_SCREEN_SAVER_RESET));
    av_push(tags_all, newSVpvn("SCREEN_SAVER_RESET", 18));
    newCONSTSUB(stash, "SELECTION_CLEAR", newSViv(XCB_SELECTION_CLEAR));
    av_push(tags_all, newSVpvn("SELECTION_CLEAR", 15));
    newCONSTSUB(stash, "SELECTION_NOTIFY", newSViv(XCB_SELECTION_NOTIFY));
    av_push(tags_all, newSVpvn("SELECTION_NOTIFY", 16));
    newCONSTSUB(stash, "SELECTION_REQUEST", newSViv(XCB_SELECTION_REQUEST));
    av_push(tags_all, newSVpvn("SELECTION_REQUEST", 17));
    newCONSTSUB(stash, "SEND_EVENT_DEST_ITEM_FOCUS", newSViv(XCB_SEND_EVENT_DEST_ITEM_FOCUS));
    av_push(tags_all, newSVpvn("SEND_EVENT_DEST_ITEM_FOCUS", 26));
    newCONSTSUB(stash, "SEND_EVENT_DEST_POINTER_WINDOW", newSViv(XCB_SEND_EVENT_DEST_POINTER_WINDOW));
    av_push(tags_all, newSVpvn("SEND_EVENT_DEST_POINTER_WINDOW", 30));
    newCONSTSUB(stash, "SET_MODE_DELETE", newSViv(XCB_SET_MODE_DELETE));
    av_push(tags_all, newSVpvn("SET_MODE_DELETE", 15));
    newCONSTSUB(stash, "SET_MODE_INSERT", newSViv(XCB_SET_MODE_INSERT));
    av_push(tags_all, newSVpvn("SET_MODE_INSERT", 15));
    newCONSTSUB(stash, "STACK_MODE_ABOVE", newSViv(XCB_STACK_MODE_ABOVE));
    av_push(tags_all, newSVpvn("STACK_MODE_ABOVE", 16));
    newCONSTSUB(stash, "STACK_MODE_BELOW", newSViv(XCB_STACK_MODE_BELOW));
    av_push(tags_all, newSVpvn("STACK_MODE_BELOW", 16));
    newCONSTSUB(stash, "STACK_MODE_BOTTOM_IF", newSViv(XCB_STACK_MODE_BOTTOM_IF));
    av_push(tags_all, newSVpvn("STACK_MODE_BOTTOM_IF", 20));
    newCONSTSUB(stash, "STACK_MODE_OPPOSITE", newSViv(XCB_STACK_MODE_OPPOSITE));
    av_push(tags_all, newSVpvn("STACK_MODE_OPPOSITE", 19));
    newCONSTSUB(stash, "STACK_MODE_TOP_IF", newSViv(XCB_STACK_MODE_TOP_IF));
    av_push(tags_all, newSVpvn("STACK_MODE_TOP_IF", 17));
    newCONSTSUB(stash, "SUBWINDOW_MODE_CLIP_BY_CHILDREN", newSViv(XCB_SUBWINDOW_MODE_CLIP_BY_CHILDREN));
    av_push(tags_all, newSVpvn("SUBWINDOW_MODE_CLIP_BY_CHILDREN", 31));
    newCONSTSUB(stash, "SUBWINDOW_MODE_INCLUDE_INFERIORS", newSViv(XCB_SUBWINDOW_MODE_INCLUDE_INFERIORS));
    av_push(tags_all, newSVpvn("SUBWINDOW_MODE_INCLUDE_INFERIORS", 32));
    newCONSTSUB(stash, "TIME_CURRENT_TIME", newSViv(XCB_TIME_CURRENT_TIME));
    av_push(tags_all, newSVpvn("TIME_CURRENT_TIME", 17));
    newCONSTSUB(stash, "UNMAP_NOTIFY", newSViv(XCB_UNMAP_NOTIFY));
    av_push(tags_all, newSVpvn("UNMAP_NOTIFY", 12));
    newCONSTSUB(stash, "VISIBILITY_FULLY_OBSCURED", newSViv(XCB_VISIBILITY_FULLY_OBSCURED));
    av_push(tags_all, newSVpvn("VISIBILITY_FULLY_OBSCURED", 25));
    newCONSTSUB(stash, "VISIBILITY_NOTIFY", newSViv(XCB_VISIBILITY_NOTIFY));
    av_push(tags_all, newSVpvn("VISIBILITY_NOTIFY", 17));
    newCONSTSUB(stash, "VISIBILITY_PARTIALLY_OBSCURED", newSViv(XCB_VISIBILITY_PARTIALLY_OBSCURED));
    av_push(tags_all, newSVpvn("VISIBILITY_PARTIALLY_OBSCURED", 29));
    newCONSTSUB(stash, "VISIBILITY_UNOBSCURED", newSViv(XCB_VISIBILITY_UNOBSCURED));
    av_push(tags_all, newSVpvn("VISIBILITY_UNOBSCURED", 21));
    newCONSTSUB(stash, "VISUAL_CLASS_DIRECT_COLOR", newSViv(XCB_VISUAL_CLASS_DIRECT_COLOR));
    av_push(tags_all, newSVpvn("VISUAL_CLASS_DIRECT_COLOR", 25));
    newCONSTSUB(stash, "VISUAL_CLASS_GRAY_SCALE", newSViv(XCB_VISUAL_CLASS_GRAY_SCALE));
    av_push(tags_all, newSVpvn("VISUAL_CLASS_GRAY_SCALE", 23));
    newCONSTSUB(stash, "VISUAL_CLASS_PSEUDO_COLOR", newSViv(XCB_VISUAL_CLASS_PSEUDO_COLOR));
    av_push(tags_all, newSVpvn("VISUAL_CLASS_PSEUDO_COLOR", 25));
    newCONSTSUB(stash, "VISUAL_CLASS_STATIC_COLOR", newSViv(XCB_VISUAL_CLASS_STATIC_COLOR));
    av_push(tags_all, newSVpvn("VISUAL_CLASS_STATIC_COLOR", 25));
    newCONSTSUB(stash, "VISUAL_CLASS_STATIC_GRAY", newSViv(XCB_VISUAL_CLASS_STATIC_GRAY));
    av_push(tags_all, newSVpvn("VISUAL_CLASS_STATIC_GRAY", 24));
    newCONSTSUB(stash, "VISUAL_CLASS_TRUE_COLOR", newSViv(XCB_VISUAL_CLASS_TRUE_COLOR));
    av_push(tags_all, newSVpvn("VISUAL_CLASS_TRUE_COLOR", 23));
    newCONSTSUB(stash, "WINDOW_CLASS_COPY_FROM_PARENT", newSViv(XCB_WINDOW_CLASS_COPY_FROM_PARENT));
    av_push(tags_all, newSVpvn("WINDOW_CLASS_COPY_FROM_PARENT", 29));
    newCONSTSUB(stash, "WINDOW_CLASS_INPUT_ONLY", newSViv(XCB_WINDOW_CLASS_INPUT_ONLY));
    av_push(tags_all, newSVpvn("WINDOW_CLASS_INPUT_ONLY", 23));
    newCONSTSUB(stash, "WINDOW_CLASS_INPUT_OUTPUT", newSViv(XCB_WINDOW_CLASS_INPUT_OUTPUT));
    av_push(tags_all, newSVpvn("WINDOW_CLASS_INPUT_OUTPUT", 25));
    newCONSTSUB(stash, "WINDOW_NONE", newSViv(XCB_WINDOW_NONE));
    av_push(tags_all, newSVpvn("WINDOW_NONE", 11));
    newCONSTSUB(stash, "_NET_WM_STATE_ADD", newSViv(1));
    av_push(tags_all, newSVpvn("_NET_WM_STATE_ADD", 17));
    newCONSTSUB(stash, "_NET_WM_STATE_REMOVE", newSViv(0));
    av_push(tags_all, newSVpvn("_NET_WM_STATE_REMOVE", 20));
    newCONSTSUB(stash, "_NET_WM_STATE_TOGGLE", newSViv(2));
    av_push(tags_all, newSVpvn("_NET_WM_STATE_TOGGLE", 20));
}
